@@ -14,4 +14,5 @@
 
 """Overlaoding of various Qiskit functionality"""
 
-from .circuit import QuantumCircuit
+import kaleidoscope.qiskit.overload.circuit
+import kaleidoscope.qiskit.overload.statevector
